from pathlib import Path
from rich import print
import os
import subprocess as sp
from pnpm import helpers as hp

# helpers
def _params(length=3):
    return " ".join([f"${i}" for i in range(1, length+1)])

def alias(name, executable, _params_length):
    return "alias " + name + "='() { " + executable + " " + _params(_params_length) + "}'"

def install():
    print("Installing pnpm...")
    PATH = hp.abs_path()

    if 'zsh' in os.environ.get("SHELL", ""):
        print('Installing with zsh')
        with open(Path.home() / ".zshrc", 'r') as f:
            if "alias pnpm" in f.read():
                return print('pnpm is already installed!')
            
        with open(Path.home() / ".zshrc", 'a') as f:
            executable = f"python3 {hp.abs_path('/pnpm')}"
            f.write(alias('pnpm', executable, 5))
            


from rich import console as _console, print, inspect
console = _console.Console()

from .config import config
from .script import * 


import json
import os
import sys
import time

class spawn():
    def __init__(self, signature, *a, **k):
        self.signature = signature
        self.start = time.time()
        process(signature, *a, **k)
        self.log()
    
    def log(self, *a, **k):
        pipe = "┣"  
        if (len(a) == 0): pipe = "┃"
        console.print(f"[dim]{pipe}", " ".join(a), **k, style="white")
    
    def warn(self, *a, **k):
        # pipe = "┃"
        warn(f"[dim white]", "".join(a), **k)

    def fail(self, msg="Fail"):
        self.log()
        self.done(msg, "red")

    def done(self, msg=None, color="green"):
        if msg is None:
            self.log()
            msg = "Done" 
        console.print("[dim]┗", f"[bold {color}]{msg}", f"in {round(time.time()-self.start, 3)} seconds\n")
    
    def input(self, msg=None, options=""):
        if msg is None:
            self.log()
            msg = "" 

        console.print("[dim]┗", f"[bold italic]{msg}")
        return input(f"{options} ⇝ ")

def warn(*args, **kwargs):
    console.print("× ", *args, **kwargs, style="#FF851B bold")


def process(*a, **k):
    console.print("\n[dim white]┏", "[bold]" + " ".join(a), **k, style="cyan")

def info(*args, **kwargs):
    console.print("\n┏", "[bold]" + " ".join(args), **kwargs, style="cyan")
    

def success(*args, **kwargs):
    console.print("\n ", *args, **kwargs, style="cyan")

def status(cmd):
    return console.status(f"Running [italic bold]{cmd}...", spinner="arrow3", spinner_style="cyan")



import subprocess as sb
import sys
import json
from script import config
import os

_params = json.loads(sys.argv[1]) if len(sys.argv)>1 else {}

def params(key=None):
    if key is None:
        return _params

    key = str(key)
    if key in _params:
        return _params[key]
    return None

env = params('env') or "dev"
pkg_manager = params('use') or config('manager')

if params("reload") or env=='prod':
    sb.call(f"pip3 install -r .pnpm/requirements.txt", shell=True)
    sb.call(f"{pkg_manager} install", shell=True)

def shell(cmd):
    sb.call(cmd, shell=True)

def npm(cmd):
    shell(f"npm {cmd}")
    
def run(script):
    sb.call(f"python3 .pnpm/scripts/{script}", shell=True)

def popen(cmd):
    proc = sb.Popen(cmd, stdout=sb.PIPE, shell=True)
    return proc.communicate()[0] == 0
    


import yaml
_config = None

with open(".pnpm/config.yml", "r") as file:
    _config = yaml.load(file, Loader=yaml.FullLoader)

def config(key=None):
    if key is None:
        return _config
    if key in _config:
        return _config[key]
    return None


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pnpm', 'pnpm.generator.__pkg__..pnpm.scripts.script']

package_data = \
{'': ['*'],
 'pnpm': ['generator/__pkg__/*',
          'generator/__pkg__/.pnpm/*',
          'generator/__pkg__/.pnpm/scripts/*',
          'generator/__pkg__/__tests__/*',
          'generator/__pkg__/docs/*',
          'generator/__pkg__/src/*',
          'generator/__pkg__/src/.build_assets/*',
          'generator/__pkg__/src/icons/*',
          'generator/__pkg__/src/pragmas/*',
          'generator/__pkg__/src/styles/*']}

install_requires = \
['PyYAML>=5.4.1,<6.0.0',
 'click>=7.1.2,<8.0.0',
 'numpy>=1.20.1,<2.0.0',
 'rglob>=1.7,<2.0',
 'rich>=9.13.0,<10.0.0']

setup_kwargs = {
    'name': 'pnpm',
    'version': '1.0.9',
    'description': '',
    'long_description': None,
    'author': 'robo-monk',
    'author_email': 'rrobomonk@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



import re
import subprocess as sb

regex = r"Location: ([^ ]+)"
_path = sb.check_output("pip3 show pnpm", shell=True).decode('utf-8').replace("\n", " ")
_path = re.search(regex, _path).group(1) + "/pnpm"

def abs_path(sub=''):
    return _path  + sub

